@@ -20,21 +20,17 @@ Miscellaneous utility classes and functions for the dx-app-wizard command-line t
 
 from __future__ import print_function, unicode_literals, division, absolute_import
 
-import os, sys, shutil, subprocess, re, json, platform
+import os, sys, shutil, subprocess, re, json
 import stat
 
 from ..utils.printing import (BOLD, DNANEXUS_LOGO, ENDC, fill)
 from ..cli import prompt_for_yn
 from ..compat import input, open
-# Import pyreadline3 on Windows with Python >= 3.5
-if platform.system() == 'Windows' and  sys.version_info >= (3, 5):
-    import pyreadline3 as readline
-else:
-    try:
-        # Import gnureadline if installed for macOS
-        import gnureadline as readline
-    except ImportError as e:
-        import readline
+try:
+    # Import gnureadline if installed for macOS
+    import gnureadline as readline
+except ImportError as e:
+    import readline
 
 from . import python
 from . import bash
@@ -49,8 +45,7 @@ completer_state = {
 }
 
 try:
-    import rlcompleter
-    readline.parse_and_bind("tab: complete")
+    readline.parse_and_bind("bind ^I rl_complete" if "libedit" in (readline.__doc__ or "") else "tab: complete")
     readline.set_completer_delims("")
     completer_state['available'] = True
 except ImportError:
@@ -63,8 +58,8 @@ class Completer():
 
     def complete(self, text, state):
         if state == 0:
-            self.matches = filter(lambda choice: choice.startswith(text),
-                                  self.choices)
+            self.matches = list(filter(lambda choice: choice.startswith(text),
+                                  self.choices))
 
         if self.matches is not None and state < len(self.matches):
             return self.matches[state]
